@@ -29,6 +29,7 @@ from lammps import lammps
 import calphy.lattice as pl
 import pyscal.core as pc
 from ase.io import read, write
+from pyscal.trajectory import Trajectory
 
 
 def create_object(cores, directory, timestep):
@@ -139,6 +140,14 @@ def convert_to_data_file(inputfile, outputfile, ghost_elements=0):
             for line in lines:
                 fout.write(line)
 
+def get_structures(file, species, index=None):
+    traj = Trajectory(file)
+    if index is None:
+        aseobjs = traj[:].to_ase(species=species)
+    else:
+        aseobjs = traj[index].to_ase(species=species)
+    return aseobjs
+
 def set_hybrid_potential(lmp, options, eps):
     pc =  options.pair_coeff[0]
     pcraw = pc.split()
