@@ -118,6 +118,7 @@ class Calculation(InputTemplate):
 
         #add second level options; for example spring constants
         self._spring_constants = None
+        self._ghost_element_count = 0
         
         self.md = InputTemplate()
         self.md.timestep = 0.001
@@ -173,7 +174,22 @@ class Calculation(InputTemplate):
             return "None"
         else:
             return str(val)
-            
+
+    def to_bool(self, val):        
+        if val == "True":
+            val = True
+        elif val == "False":
+            val = False
+        elif val == 1:
+            val = True
+        elif val == 0:
+            val = False
+        elif val == "1":
+            val = True
+        elif val == "0":
+            val = False
+        return val
+
     @property
     def element(self):
         return self._element
@@ -463,8 +479,8 @@ class Calculation(InputTemplate):
 
     @equilibration_control.setter
     def equilibration_control(self, val):
-        if val not in ["berendsen", "nose-hoover"]:
-            raise ValueError("Equilibration control should be either berendsen or nose-hoover")
+        if val not in ["berendsen", "nose-hoover", None]:
+            raise ValueError("Equilibration control should be either berendsen or nose-hoover or None")
         self._equilibration_control = val
 
     @property
@@ -473,6 +489,7 @@ class Calculation(InputTemplate):
     
     @melting_cycle.setter
     def melting_cycle(self, val):
+        val = self.to_bool(val)
         if isinstance(val, bool):
             self._melting_cycle = val
         else:
