@@ -565,8 +565,8 @@ def integrate_rs(simfolder, f0, t, natoms, p=0, nsims=5,
     p = p/(10000*160.21766208)
     
     for i in range(1, nsims+1):
-        fdx, fp, fvol, flambda = np.loadtxt(os.path.join(simfolder, "forward_%d.dat"%i), unpack=True, comments="#")
-        bdx, bp, bvol, blambda = np.loadtxt(os.path.join(simfolder, "backward_%d.dat"%i), unpack=True, comments="#")
+        fdx, fp, fvol, flambda = np.loadtxt(os.path.join(simfolder, "ts.forward_%d.dat"%i), unpack=True, comments="#")
+        bdx, bp, bvol, blambda = np.loadtxt(os.path.join(simfolder, "ts.backward_%d.dat"%i), unpack=True, comments="#")
         
         if scale_energy:
             fdx /= flambda
@@ -624,8 +624,8 @@ def integrate_ps(simfolder, f0, natoms, pi, pf, nsims=1,
     ws = []
 
     for i in range(1, nsims+1):
-        _, fp, fvol, _ = np.loadtxt(os.path.join(simfolder, "forward_%d.dat"%i), unpack=True, comments="#")
-        _, bp, bvol, _ = np.loadtxt(os.path.join(simfolder, "backward_%d.dat"%i), unpack=True, comments="#")
+        _, fp, fvol, _ = np.loadtxt(os.path.join(simfolder, "ps.forward_%d.dat"%i), unpack=True, comments="#")
+        _, bp, bvol, _ = np.loadtxt(os.path.join(simfolder, "ps.backward_%d.dat"%i), unpack=True, comments="#")
         
         fvol = fvol/natoms
         bvol = bvol/natoms
