@@ -211,6 +211,26 @@ class Phase:
         lmp.command("run               0")
         lmp.command("undump            2")
 
+    def get_structures(self, stage="fe", direction="forward", n_iteration=1):
+        """
+        """
+        species = self.calc.element
+        filename = None
+
+        if stage == "fe":
+            filename = os.path.join(self.simfolder, "conf.equilibration.dump")
+        elif stage == "ts":
+            if direction == "forward":
+                filename = os.path.join(self.simfolder, "traj.ts.forward_%d.dat"%n_iteration)
+            elif direction == "backward":
+                filename = os.path.join(self.simfolder, "traj.ts.backward_%d.dat"%n_iteration)
+
+        structures = None
+        if filename is not None:
+            structures = ph.get_structures(filename, species, index=None)
+
+        return structures
+
     def check_if_melted(self, lmp, filename):
         """
         """
@@ -685,10 +705,10 @@ class Phase:
         lmp.command("pair_coeff       %s"%pcnew1)
         lmp.command("pair_coeff       %s"%pcnew2)
 
-        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${flambda}\" screen no file forward_%d.dat"%iteration)
+        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${flambda}\" screen no file ts.forward_%d.dat"%iteration)
 
         if self.calc.n_print_steps > 0:
-            lmp.command("dump              d1 all custom %d traj.rs.forward_%d.dat id type mass x y z vx vy vz"%(self.calc.n_print_steps,
+            lmp.command("dump              d1 all custom %d traj.ts.forward_%d.dat id type mass x y z vx vy vz"%(self.calc.n_print_steps,
                 iteration))
 
         lmp.command("run               %d"%self.calc._n_sweep_steps)
@@ -724,10 +744,10 @@ class Phase:
         lmp.command("pair_coeff       %s"%pcnew2)
 
         #apply fix and perform switching        
-        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${blambda}\" screen no file backward_%d.dat"%iteration)
+        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${blambda}\" screen no file ts.backward_%d.dat"%iteration)
 
         if self.calc.n_print_steps > 0:
-            lmp.command("dump              d1 all custom %d traj.rs.backward_%d.dat id type mass x y z vx vy vz"%(self.calc.n_print_steps,
+            lmp.command("dump              d1 all custom %d traj.ts.backward_%d.dat id type mass x y z vx vy vz"%(self.calc.n_print_steps,
                 iteration))
 
         lmp.command("run               %d"%self.calc._n_sweep_steps)
@@ -825,7 +845,7 @@ class Phase:
 
         lmp.command("fix               f2 all npt temp %f %f %f %s %f %f %f"%(t0, tf, self.calc.md.thermostat_damping[1],
                                         self.iso, p0, pf, self.calc.md.barostat_damping[1]))
-        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${lambda}\" screen no file forward_%d.dat"%iteration)
+        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${lambda}\" screen no file ts.forward_%d.dat"%iteration)
         lmp.command("run               %d"%self.calc._n_sweep_steps)
 
         lmp.command("unfix             f2")
@@ -852,7 +872,7 @@ class Phase:
 
         lmp.command("fix               f2 all npt temp %f %f %f %s %f %f %f"%(tf, t0, self.calc.md.thermostat_damping[1],
                                         self.iso, pf, p0, self.calc.md.barostat_damping[1]))
-        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${lambda}\" screen no file backward_%d.dat"%iteration)
+        lmp.command("fix               f3 all print 1 \"${dU} $(press) $(vol) ${lambda}\" screen no file ts.backward_%d.dat"%iteration)
         lmp.command("run               %d"%self.calc._n_sweep_steps)
 
         lmp.close()
@@ -911,7 +931,7 @@ class Phase:
 
         lmp.command("fix               f2 all npt temp %f %f %f %s %f %f %f"%(t0, t0, self.calc.md.thermostat_damping[1],
                                         self.iso, p0, pf, self.calc.md.barostat_damping[1]))
-        lmp.command("fix               f3 all print 1 \"${dU} ${pp} $(vol) ${lambda}\" screen no file forward_%d.dat"%iteration)
+        lmp.command("fix               f3 all print 1 \"${dU} ${pp} $(vol) ${lambda}\" screen no file ps.forward_%d.dat"%iteration)
         lmp.command("run               %d"%self.calc._n_sweep_steps)
 
         lmp.command("unfix             f2")
@@ -929,7 +949,7 @@ class Phase:
 
         lmp.command("fix               f2 all npt temp %f %f %f %s %f %f %f"%(t0, t0, self.calc.md.thermostat_damping[1],
                                         self.iso, pf, p0, self.calc.md.barostat_damping[1]))
-        lmp.command("fix               f3 all print 1 \"${dU} ${pp} $(vol) ${lambda}\" screen no file backward_%d.dat"%iteration)
+        lmp.command("fix               f3 all print 1 \"${dU} ${pp} $(vol) ${lambda}\" screen no file ps.backward_%d.dat"%iteration)
         lmp.command("run               %d"%self.calc._n_sweep_steps)
 
         lmp.close()
